# GBSL Turtle

Ermöglicht Typ-Hinweise für das Standard-Turtle modul

### Package and upload to pip


```sh
rm -rf build/ dist/ gbsl_turtle.egg-info/
python3 setup.py sdist bdist_wheel
python3 -m twine upload dist/*
```
